@@ -4,7 +4,7 @@ from django.utils.safestring import mark_safe
 import logging
 logger = logging.getLogger("x-pages")
 
-def page(request, route=None):
-    ctx = route.get_context(request)
-    route.increment_view_count(request)
+def page(request):
+    ctx = request.route.get_context(request)
+    request.route.increment_view_count(request)
     return render_to_response(request.theme.template().page, ctx, RequestContext(request))
