@@ -1,5 +1,6 @@
 from django.conf import settings
 from xadrpy.i18n import conf as i18n_conf
+from django.utils.translation import ugettext_lazy as _
 import os
 
 DEFAULT_SITE_ID = getattr(settings, 'SITE_ID')
@@ -13,4 +14,11 @@ META_HANDLER = "xadrpy.router.libs.MetaHandler"
 
 META_HANDLER_CLS = None
 
-VERSION = 1
\ No newline at end of file
+VERSION = 1
+
+RELATIVE_FROM = (
+    ('absolute', _("Absolute path")),
+    ('settings', _("location of settings.py")),
+    ('document', _("document root")),
+    
+)
\ No newline at end of file
